;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; Loading this file installs CG/JS.
;; Please see readme.txt for more information
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

(in-package :user)

(eval-when (compile eval load)
  (require :shell)
  (use-package :excl.shell))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; validate files

(let ((platform-file
       (directory
	(merge-pathnames
	 "PLATFORM-*"
	 (path-pathname *load-pathname*)))))
  (or platform-file
      (error "Could not find the PLATFORM file."))
  
  (when (> (length platform-file) 1)
    (error "There is more than one PLATFORM file: ~a." platform-file))
  (setq platform-file (car platform-file))
  
  (or (=~ "^PLATFORM-(.*)" (file-namestring platform-file))
      (error "Cannot parse the PLATFORM file."))
  
  (let ((expected-platform $1)
	(current-platform
	 (format nil "~a~a" (symbol-name sys::.os.) #+smp "smp" #-smp "")))
    (or (string-equal expected-platform current-platform)
	(error
	 "The current platform (~a) does not match the downloaded version (~a)."
	 current-platform expected-platform)))
  ;; We are on the correct platform, fall through...
  )

;; HTML files needed for the operation of CG/JS
;; (this variable's value is generated by build_cgjs.sh)
(defvar *html-files* '("cgjs.html" "ssl-not-found.html" "browser-not-supported.html" ))

(defvar *extra-files*)
(setq *extra-files* nil)

(dolist (file *html-files*)
  (setq file (merge-pathnames file *load-pathname*))
  (or (probe-file file)
      (error "~a does not exist." file))
  (push file *extra-files*))
;; All *html-files* exist...

;; These two are directories but the pathname is specified as
;; a file, so merging works below.
(defvar *cg2js-directory* (merge-pathnames "code.cg2js" *load-pathname*))
(defvar *idejs-directory* (merge-pathnames "code.idejs" *load-pathname*))

(dolist (d (list *cg2js-directory* *idejs-directory*))
  (or (probe-file d)
      (error "~a does not exist." d)))

;; MD5 checksums of the incoming files
;; (this variable's value is generated by build_cgjs.sh)
(defvar *checksums* 
'(
(#xedc681fc9f4eb8104445954b2eaa54ed . "./code.cg2js/cg-scroll-bar-mixin.fasl")
(#x819518b1428ae275c1ff3c5b8cd4ef1d . "./code.cg2js/cg-gesture-emulation.fasl")
(#x04012a3274546bb0a5186d0ec4b38ef4 . "./code.cg2js/cg-grid-widget.fasl")
(#x92ab1101d1744d8e2a107b692d141bfb . "./code.cg2js/cg-utility-dialog.fasl")
(#x7a4a638589fa99cb6ce272bff5b4f53f . "./code.cg2js/cg-wrap-string.fasl")
(#x824dcae111aa3f4f017478da4a31fa26 . "./code.cg2js/cg-editable-text.fasl")
(#xa51591436f63eb428ab93b69c6c44c3f . "./code.cg2js/cg-base.fasl")
(#x89b648100aff1e4c04c2cac0928d8e4b . "./code.cg2js/cg-lisp-text.fasl")
(#xe6495491fa8b7d0f45e389441d3b4a17 . "./code.cg2js/cg-intersect.fasl")
(#xde171de91926b8f9e020a2675cfb3c7d . "./code.cg2js/cg-choose-printer.fasl")
(#xe846ca69ade5f18fd3ad324955581102 . "./code.cg2js/cg-multi-line-lisp-text.fasl")
(#xc0da5819097cc5568d05d73dd947b0f4 . "./code.cg2js/cg-outline-drag-and-drop.fasl")
(#x1170fcfad31965fba6ff3b9f67e330f9 . "./code.cg2js/cg-font-dialog.fasl")
(#x025c36559048be4981cc64873f244bb4 . "./code.cg2js/cg-comtab.fasl")
(#xbd2212bbe72108f0c09cce772d876514 . "./code.cg2js/cg-tooltip.fasl")
(#x78835e29f476f615847d618558b4b05e . "./code.cg2js/cg-chart-or-plot.fasl")
(#xbb2eccac69ff91e3118c0c293311dfde . "./code.cg2js/cg-get-pixmap.fasl")
(#x3527417b58a71c8c1b27b3353a5f1b53 . "./code.cg2js/cg-status-bar.fasl")
(#x379f1e54cd0432923e4c9d11eec2c2df . "./code.cg2js/cg-tab-control.fasl")
(#x134a242dd31c35573430d4776d7d7d09 . "./code.cg2js/cg-icon-pixmap.fasl")
(#x72cfc328e74715fc0cab2764350d7ae3 . "./code.cg2js/cg-list-view.fasl")
(#x18257a9cf5a93de3716a89e680b12bff . "./code.cg2js/cg-text-edit-pane-file-io.fasl")
(#x61944e5c49613354ac5f0d01c627b1de . "./code.cg2js/cg-rich-edit-pane-clipboard.fasl")
(#xb4eaa1452601470181c95bfbd79bd822 . "./code.cg2js/cg-scrolling-static-text.fasl")
(#xbf4b717e6148f93e6bdef5da731258b9 . "./code.cg2js/cg-project-window.fasl")
(#x38715f2b65f32b95eab1062ebd64108f . "./code.cg2js/cg-multi-picture-button-drag-and-drop.fasl")
(#xf6d375964d2ffa13ea314094a9b0c6f7 . "./code.cg2js/cg-drag-and-drop.fasl")
(#x98030caaf7341340c302180ea99da207 . "./code.cg2js/cg-scaling-stream.fasl")
(#x0c4c8c923c4a21fe63aacd5784a0d312 . "./code.cg2js/cg-rich-edit-pane.fasl")
(#x3d779ef230a4d8b54794d9ef207f3c12 . "./code.cg2js/cg-bitmap-stream.fasl")
(#x60d110d5a045c81e4e977c07b2a2f6e1 . "./code.cg2js/cg-menu.fasl")
(#x3f64b65d05db8e86cb034a58a7136b5a . "./code.cg2js/cg-lisp-edit-pane.fasl")
(#xbec8956c7280882b657d97a91e32f12e . "./code.cg2js/cg-intersect-posbox.fasl")
(#xca295b43be5f278659b8bc7061a108ae . "./code.cg2js/cg-split-bar.fasl")
(#x3871d2631e5f0e835af3bc9d5c43b997 . "./code.cg2js/cg-drag-and-drop-image.fasl")
(#x5ae5ae13b73597135d7f8c3aafcec5ce . "./code.cg2js/cg-timer.fasl")
(#x120e35832031775c7bf95482d28b4476 . "./code.cg2js/cg-text-or-combo.fasl")
(#x84ef117b425198f9603e0b7b3f1d9102 . "./code.cg2js/cg-picture-widget-palette.fasl")
(#xa9618344f1d4c63f7dde1584cd0b7925 . "./code.cg2js/cg-string-dialog.fasl")
(#x28c55a4c7f4ebe61bcad2f66008fc842 . "./code.cg2js/cg-clipboard-pixmap.fasl")
(#xd88ec9d4435557dc51ccf077e81ea460 . "./code.cg2js/cg-menu-tooltip.fasl")
(#x60b54304666c1ad9236447fb3bdca9e9 . "./code.cg2js/cg-outline.fasl")
(#x1ef2687214baf057c1d9cbcfb90ffb4c . "./code.cg2js/cg-lettered-menu.fasl")
(#x420d79ff0f71e366bc2c394855c2b613 . "./code.cg2js/cg-graphics-context.fasl")
(#x0f13bdb3e885e6a77b8198fdbd041919 . "./code.cg2js/cg-item-list.fasl")
(#x9042f72d8d042e194d498ee3859f4bdb . "./code.cg2js/cg-caret.fasl")
(#x918a32feb8353055510afd2d9fab11d5 . "./code.cg2js/cg-printing.fasl")
(#x79920ff959cd5451eec5660aff76117c . "./code.cg2js/cg-pixmap-printing.fasl")
(#xa1e4383bfd2c5686ad9bff835b11b612 . "./code.cg2js/cg-progress-indicator.fasl")
(#x96539ac32a5564709b8893bf4e4719e2 . "./code.cg2js/cg-dde-utils.fasl")
(#x3fe069b7fcf18194223c133e5525523e . "./code.cg2js/cg-plot-widget.fasl")
(#x0bf46c8f8276700b02c4a5866c4ff620 . "./code.cg2js/cg-os-window.fasl")
(#x0368f8a7ae6f658cff90713f5f6f6020 . "./code.cg2js/cg-calendar.fasl")
(#x099fd83663a37df92aea31261a43fe1f . "./code.cg2js/cg-chart-widget.fasl")
(#x251e95285f463289e3240f066c93e08b . "./code.cg2js/cg-file-dialog.fasl")
(#xf51008b261518dd5815d0ddea1b8c703 . "./code.cg2js/cg-nodes.fasl")
(#xb9077b2d247f7a80d9c3c8fc90fae074 . "./code.cg2js/cg-lamp.fasl")
(#xddb01fd3369d50d74635f6b49f983046 . "./code.cg2js/cg-html-dialog.fasl")
(#xecb1b00b6c298c3cc7c90521c1761c33 . "./code.cg2js/cg-multi-picture-button-tooltip.fasl")
(#x1527d9238071fde5b61648bc1f3921b6 . "./code.cg2js/cg-class-slot-grid.fasl")
(#xc8006226e0216f8ddb03b4b6b65faaf7 . "./code.cg2js/cg-choice-list.fasl")
(#xb29bfa10390176a2a1cba8ccf11252e4 . "./code.cg2js/cg-multi-picture-button.fasl")
(#x9a416c93b6821658d8db71567d270ebf . "./code.cg2js/cg-multi-line-editable-text.fasl")
(#xa8437736700c1e9d77158a8860512bec . "./code.cg2js/cg-hotspot.fasl")
(#x8c560e815daca09660617d8eccd77513 . "./code.cg2js/cg-property.fasl")
(#xc2034f4efe05e0ce393cd2f7067e1066 . "./code.cg2js/cg-dropping-outline.fasl")
(#xffafe9dade713c40e1bce36f6a48e9cc . "./code.cg2js/cg-template-string.fasl")
(#xa37f751ec05539a9f5a9ab03a431ed66 . "./code.cg2js/cg-palette.fasl")
(#xcb0774153dc3da9fddb9435d5bcacce7 . "./code.cg2js/cg-selected-object.fasl")
(#x5bf9ba2af103ef27edc97e157c583e21 . "./code.cg2js/cg-up-down-control.fasl")
(#xd1565ce0d274334aab52b8b2e12edd68 . "./code.cg2js/cg-keyboard-shortcuts.fasl")
(#x81a170bd790c5d7304cd11bc31ae969f . "./code.cg2js/cg-layout.fasl")
(#xa4b0ab59729dd8fa35eceb64447a5647 . "./code.cg2js/cg-get-position.fasl")
(#x76041972620d08266870c2b6c9d80b2c . "./code.cg2js/cg-lisp-widget.fasl")
(#x46b0886a33c993edd8922d1b8b0da1f9 . "./code.cg2js/cg-grid-widget-drag-and-drop.fasl")
(#x828d30e485a0a6d13c6b4c6d946a76a0 . "./code.cg2js/cg-object-editor.fasl")
(#x1a9e86a11cfaafdc645ebb7368e8e905 . "./code.cg2js/cg-class-grid.fasl")
(#x926f90be894dff3ed58030ee36a9435b . "./code.cg2js/cg-yes-no-string.fasl")
(#x648448654312357a91827afafc0d5d23 . "./code.cg2js/cg-toggling-widget.fasl")
(#xb46cd516b8242ec2dd206c403c11c8a9 . "./code.cg2js/cg-text-edit-pane-mark.fasl")
(#x88617313646ad44c05f67fcec15b63d6 . "./code.cg2js/cg-button.fasl")
(#xa03e6839276cd31da149222279e2da90 . "./code.cg2js/cg-object-editor-layout.fasl")
(#x7520532496cb193e4e3d9b2f18efd240 . "./code.cg2js/cg-scroll-bar.fasl")
(#xb873511b49b512aee80651a97ce1f3f3 . "./code.cg2js/cg-combo-box.fasl")
(#x4252e313f3b8cdc38c373fc524262ba4 . "./code.cg2js/cg-web-browser.fasl")
(#xb8d99e06c29af5962dcd642661fdf478 . "./code.cg2js/cg-drawable.fasl")
(#x618110ef352cfb2a0027bf609c29f591 . "./code.cg2js/cg-cursor-pixmap.fasl")
(#xf82b75498e7e03898c3959f300197063 . "./code.cg2js/cg-message-dialog.fasl")
(#x1b8a5ed406a706e5ebc273813783defa . "./code.cg2js/cg-text-widget.fasl")
(#x5d5bf830fc08e2cc80c5b1077b15301b . "./code.cg2js/cg-static-text.fasl")
(#x0bc2bbc83a5906d0c758b8582d92ab6a . "./code.cg2js/cg-class-support.fasl")
(#x2af50a2e81150118060c940a60dfca0e . "./code.cg2js/cg.fasl")
(#xca51beb842c0d3c835833ce1ea230c0c . "./code.cg2js/cg-directory-dialog.fasl")
(#x34d91f16813aae90df0d92244d281b01 . "./code.cg2js/cg-clipboard.fasl")
(#xd2a0d665844880639e7e68825c4fb903 . "./code.cg2js/cg-drawable-clipboard.fasl")
(#x96857352dc3a851c7e65c0a44f5dbc92 . "./code.cg2js/cg-bitmap-pane.fasl")
(#x71d44238870d1e5e26aaf90355e566b0 . "./code.cg2js/cg-bitmap-pane-clipboard.fasl")
(#x018cf11fb0d6a30901777bc6379f8f4d . "./code.cg2js/cg-check-box.fasl")
(#xa322754717b44b3fa57b6fb84045da57 . "./code.cg2js/cg-color-dialog.fasl")
(#x0a171c0d4b32da5435263446c0e062ab . "./code.cg2js/cg-text-edit-pane.fasl")
(#x04711c005cfd2292fbb197fa0e82b6dd . "./code.cg2js/cg-dialog-item.fasl")
(#x217e65be44d53d938feaa313af33a419 . "./code.cg2js/cg-edit-in-place.fasl")
(#xdb542c01863d34c505cd117468edfa12 . "./code.cg2js/cg-tray.fasl")
(#x0c133f11968e67d8e34c2d18955c46eb . "./code.cg2js/cg-paren-matching.fasl")
(#x251aeb526cf7b9777d3156947a206b46 . "./code.cg2js/cg-player.fasl")
(#x2f690321ebc9a7affc8f50f5d6e902cf . "./code.cg2js/cg-yes-no-list.fasl")
(#x2e12c6097596ce3f35878bbf30af491e . "./code.cg2js/cg-common-control.fasl")
(#xa674c607993c1a528c57ff40e078aae0 . "./code.cg2js/cg-pixmap-file-io.fasl")
(#xf49c35ec90acf3927d1e4ddec8d8d7c6 . "./code.cg2js/cg-os-widget.fasl")
(#xf79b12bcefc50d38f1956044022e8b85 . "./code.cg2js/cg-sample-file-menu.fasl")
(#xe052e707da4a809143e0781b300b8739 . "./code.cg2js/cg-trackbar.fasl")
(#x4abfe3d5ccf996dc93c440d52418668a . "./code.cg2js/cg-rich-edit.fasl")
(#xe99a1fc5565414d890eb71441d34a5a7 . "./code.cg2js/cg-find-string-dialog.fasl")
(#xd2d82224c0981d7c7887ed525bd8d0b1 . "./code.cg2js/cg-html-widget.fasl")
(#x44ce3aa961db827105f61de20dd80930 . "./code.cg2js/cg-rich-edit-pane-printing.fasl")
(#x5923cfe45abe6b052898abf2c4eca2ce . "./code.cg2js/cg-directory-dialog-os.fasl")
(#x7542d32673c656058af1e812507462b5 . "./code.cg2js/cg-acache.fasl")
(#x77e371dfcd3554703204dea20f22b5bb . "./code.cg2js/cg-shortcut-menu.fasl")
(#x11bddd71e0f15b8068b00b6b6285db1d . "./code.cg2js/cg-pixmap-widget.fasl")
(#xe3e26bd04c193a640b48087467d62dea . "./code.cg2js/cg-icon.fasl")
(#x0c09580d05ec7186eecf9a10a243e1c0 . "./code.cg2js/cg-pixmap.fasl")
(#x420387c74dbadbe0c78817e48258915c . "./code.cg2js/cg-clipboard-stack.fasl")
(#x785c18ced633f44c39ae2f7994daeb9b . "./code.cg2js/cg-outline-edit-in-place.fasl")
(#x7410d0929de5317a7c5e159eead14171 . "./code.cg2js/cg-toolbar.fasl")
(#x74289a8de831b6106819f003c1a34499 . "./code.cg2js/cg-radio-button.fasl")
(#xf609fd957439d38278cb3fc76a79ff41 . "./code.cg2js/cg-curve.fasl")
(#x9bf2805f16e9de441a13fafc0fab4c25 . "./code.cg2js/cg-picture-widget.fasl")
(#xbd7df969edc9ca2e33d752a72b4b8cff . "./code.cg2js/cg-dev.fasl")
(#x5727fd41b9582d9635ba14a736fba8b0 . "./code.cg2js/cg-group-box.fasl")
(#x709f7aa11af101f5a7d5f1ca4f693256 . "./code.cg2js/cg-fill-texture.fasl")
(#xb803d288a4765b11969f5f391c727f40 . "./code.cg2js/cg-pixmap-rotate.fasl")
(#x751c3a14ddfb4883dd33e1ee7b610d2d . "./code.idejs/ide-keyshort.fasl")
(#xb2ec7bc614a32caea4d83ed2ac88202b . "./code.idejs/ide-form.fasl")
(#x4210b13ef8b23ceccf79c938df4c5252 . "./code.idejs/ide-find-in-files.fasl")
(#xa3b9dc0a78de42b743a96aedd5ab4d45 . "./code.idejs/ide-class-grapher.fasl")
(#xbef204375b8e74cf67900933e423814a . "./code.idejs/ide-base.fasl")
(#xb1384eacf70422c3a25e85e70f82b5ef . "./code.idejs/ide-class-browser.fasl")
(#x03c082ef7fa87de39771b1f8d6dc4da6 . "./code.idejs/ide-find-definitions.fasl")
(#xbc837b4b89a7fda5648222d3076cb6d1 . "./code.idejs/ide-package-list.fasl")
(#x9c5727b777c4b258ffec9bd6debcc286 . "./code.idejs/ide-grapher.fasl")
(#xb6fcb20132fd46b33a294473449f3dd1 . "./code.idejs/ide-dev.fasl")
(#xcbedb40d4a23bc32880a39a2b7deddbf . "./code.idejs/ide.fasl")
(#xb3fa14d1af268419d6c5c7bc84bb8c9f . "./code.idejs/ide-trace.fasl")
(#x244a2f04aeb3e1c0a9644b6e8a58b469 . "./code.idejs/ide-apropos.fasl")
(#xa0602d46e34dc98e5eb95b66c5722b97 . "./code.idejs/ide-inspector.fasl")
(#xfc79d2ac1e09e1024005639023a5cf89 . "./code.idejs/ide-acache.fasl")
(#xb0d8684c045c323f4c65232f318e4038 . "./code.idejs/ide-project.fasl")
(#xf8728364a545b0bdc17910e482e70334 . "./code.idejs/ide-window-list.fasl")
(#xa14a148456ce8cca337e8a1b712f7b63 . "./code.idejs/ide-intro.fasl")
(#x31e785f8fa93e16d9f1f6c19c99fcb7e . "./code.idejs/ide-clipboard.fasl")
(#x2768e8ba408aca3fc97876a738ceede1 . "./code.idejs/ide-editor.fasl")
(#xdc727cab602b264ae8ffb21015681796 . "./code.idejs/ide-process-browser.fasl")
(#xb416d6da6de7899a8dafa3fc731ea09b . "./code.idejs/ide-patch-dialog.fasl")
(#x1b15ba38ccb6dafc771d5586c792a4ce . "./code.idejs/ide-navigator.fasl")
(#x4469068b47e063cb9811630bd05af4c2 . "./cgjs.html")
(#xdac1739373835d1a63cbafa2c3e0b06a . "./ssl-not-found.html")
(#x90c6d2a65504d45266ad9fa3a49be2f9 . "./browser-not-supported.html"))
 )

(let ((files-ok
       (dolist (checksum *checksums* t)
	 (when (/= (car checksum)
		   (md5-file
		    (merge-pathnames (cdr checksum) *load-pathname*)))
	   (return nil)))))
  (cond
   ((not files-ok)
    (error "The extracted files failed the checksum test.  ~
Please download and/or extract again."))
   (t
    (format t "Checksums on files are OK...~%"))))

;; We have validated all the files are there...

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; check for needed patches

(eval-when (compile eval load) (require :build))

(defvar *required-patches* '(#+macosx ("build" . 3)))

(dolist (required-patch *required-patches*)
  (let ((existing-patch (assoc (car required-patch)
			    (cdr (assoc :system sys::*patches*))
			    :test #'string=)))
    (when (null existing-patch)
      (error "Could not find patch info for the ~s module."
	     (car required-patch)))
    (when (not (>= (second existing-patch) (cdr required-patch)))
      ;; The build patch number is NOT >= to the one we require
      (error "~
Expected version ~d of ~s but have version ~d.  Please update ~
your lisp with update.~a and then do the CG/JS installation again."
	     (cdr required-patch) (car required-patch)
	     (second existing-patch)
	     #+mswindows "exe"
	     #-mswindows "sh"))))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; copy files

(defun copy (source dest)
  (cond
   ((file-directory-p source)
    (format t "Copy directory ~a~%" (enough-namestring source))
    (copy-directory source dest :quiet t))
   (t
    (format t "Copy file ~a~%" (enough-namestring source))
    (sys:copy-file source dest :verbose nil))))

(defvar *sys* (translate-logical-pathname (pathname "sys:")))

(cond
 ((excl::pathname-equalp (truename *sys*)
			 (path-pathname *load-truename*))
  (format t "Files are already in place, no copying requiring.~%"))
 (t ;; copy files, replacing them with new ones if they already exist
  (let (dest)
    (dolist (from *extra-files*)
      (setq dest (merge-pathnames (file-namestring from) *sys*))
      (when (probe-file dest) (delete-file dest))
      (copy from dest))
    
    (dolist (from (list *cg2js-directory* *idejs-directory*))
      (setq dest (merge-pathnames (file-namestring from) *sys*))
      ;; now make it a directory pathname
      (setq dest (pathname-as-directory dest))

      (when (probe-file dest) (delete-directory-and-files dest))
      (copy (pathname-as-directory from) dest)))))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; update develenv.cl to load CG/JS before the original version of CG

(defvar *setup-cgjs-loading* "sys:setup-cgjs-loading.cl")

;; Because users might use an ANSI lisp to install, have to make sure
;; the resulting file can be loaded into an ANSI and Modern lisp.
(with-open-file (s *setup-cgjs-loading* :direction :output
		 :if-exists :supersede)
  (format s "~
;; This file was created by install-cgjs.cl.
;; Please do not edit it.

")
  (dolist (dir (list "code.cg2js" "code.idejs"))
    (format s "
(let ((path (make-pathname
             :host \"sys\"
             :directory '(:relative \"~a\")
	     :type \"fasl\"
	     )))
  (format t \";; *require-search-list*: adding: ~~s~%\" path)
  (push path sys:*require-search-list*))

"
	    dir)))

(defvar *develenv.cl* (pathname "sys:develenv.cl"))

(when (not (probe-file *develenv.cl*))
  (setf (file-contents *develenv.cl*)
    ";; This file is loaded before images are rebuilt with update.sh/update.exe

"))

(let ((contents (file-contents *develenv.cl*)))
  (cond
   ((match-re
     (format nil "^#\\|\\|# \\(load \"sys:~a"
	     (file-namestring *setup-cgjs-loading*))
     contents
     :multiple-lines t)
    (format t "develenv.cl already correctly loads CG/JS.~%"))
   ((match-re
     (format nil "^#\\+ignore \\(load \"sys:~a"
	     (file-namestring *setup-cgjs-loading*))
     contents
     :multiple-lines t)
    (format t "develenv.cl: CG/JS disabled; will enable.~%")
    (setf (file-contents *develenv.cl*)
      (replace-re  contents
		  (format nil "^#\\+ignore *\\(load \"sys:~a"
			  (file-namestring *setup-cgjs-loading*))
		  (format nil "#||# (load \"sys:~a"
			  (file-namestring *setup-cgjs-loading*))
		  :multiple-lines t
		  :count 1)))
   (t
    (format t "develenv.cl: adding CG/JS initialization.~%")
    (setf (file-contents *develenv.cl*)
      (concatenate 'simple-string
	contents
	(format nil "~

;; To disable the use of CG/JS and go back to the originally released
;; (and possibly patched) version of CG/IDE, change the #||# to
;; #+ignore on the following line and the rebuild images by running
;; update.sh or update.exe, depending on your platform:
#||# (load \"sys:~a\")~%~%"
		(file-namestring *setup-cgjs-loading*)))))))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; success!

(let ((msg (format nil "~
CG/JS installation successful!

NOTE: to use CG/JS you must rebuild images by running 'update.~a'
      in the Allegro CL directory (~a)."
		   #+mswindows "exe"
		   #-mswindows "sh"
		   *sys*)))
  #-mswindows (format t "~&~%~a~%" msg)
  #+mswindows (excl::internal-message-box msg "CG/JS Installation" :type :ok))
